#!/usr/bin/env bash
#
# v8-tarball.sh

BRANCH=${1:+-b ${1}}

set -e

echo
echo "*** Cloning v8 repository ***"
echo "-----------------------------"
git clone ${BRANCH} "https://github.com/v8/v8.git" "v8" && cd "v8"

echo
echo "*** Downloading dependencies ***"
echo "--------------------------------"
make dependencies

echo
echo "*** Cleaning up ***"
echo "-------------------"
find . -depth -type d -name .git -exec rm -rf {} \;
find . -depth -type d -name .svn -exec rm -rf {} \;

echo
echo "*** Extracting version ***"
echo "--------------------------"
VERSION="$(head -1 ChangeLog 2>/dev/null | sed -e 's/.*Version //')"
[ -z "${VERSION}" ] && { echo "Error extracting version!"; echo; exit 2; }

echo
echo "*** Creating archive ***"
echo "------------------------"
cd .. && rm -rf "v8-${VERSION}" && mv -f "v8" "v8-${VERSION}"
tar cJf "v8-${VERSION}.tar.xz" "v8-${VERSION}" && rm -rf "v8-${VERSION}"
echo "Finished v8-${VERSION}"
echo
