%{!?python_abi:      %define python_abi      %(%{__python} -c "import sys; print sys.version[:3]")}
%{!?python_sitelib:  %define python_sitelib  %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%define pkg    v8
%define ver    3.25.12
%define maj    %(echo %{ver} | cut -d'.' -f1)


Summary:       The V8 JavaScript Engine
Name:          %{pkg}
Version:       %{ver}
Release:       1%{?dist}%{?pext}
License:       BSD
Group:         System Environment/Libraries
Source0:       http://github.com/%{name}/%{name}/%{name}-%{version}.tar.xz
Source1:       %{name}-tarball.sh
Patch0:        %{name}-3.25.7-build.patch
URL:           http://code.google.com/p/%{name}/
Buildroot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:        Google Inc.
BuildRequires: python26 >= 2.6 readline-devel
BuildArch:     i486 x86_64

%description
V8 is Google's open source JavaScript engine. It is written in C++ and is
used in Google Chrome, the open source browser from Google. V8 implements
ECMAScript as specified in ECMA-262, 5th edition, and runs in standalone
mode, or can be embedded into any C++ application.


%package       devel
Summary:       Development tools for V8
Group:         Development/Libraries
Requires:      %{name} = %{version}-%{release}
Requires:      pkgconfig

%description   devel
The %{name}-devel package contains the libraries and header files for
developing software using V8.


%package       static
Summary:       Static libraries for V8
Group:         Development/Libraries
Requires:      %{name}-devel = %{version}-%{release}

%description   static
The %{name}-static package contains the statically linkable libraries
for V8.


%prep
%setup -q
%patch0 -p1

# Fix config
%{__sed} -i -e 's#@PREFIX@#%{_prefix}#g'     \
	    -e 's#@LIBDIR@#%{_libdir}#g'     \
	    -e 's#@INCDIR@#%{_includedir}#g' \
	    -e 's#@VERSION@#%{version}#g'    \
	    %{name}.pc

# Fix permissions
%{__chmod} -x include/*.h

# Fix interpreter path
for FILE in `find build -type f -exec egrep -l '(?:exec|env)?[/ ]python' {} \;`; do
  %{__sed} -i -e 's,\([/ ]python\),\12.6,' ${FILE}
done


%build
export CC="%{__cc}"
export CXX="%{__cxx}"
export LINK="%{__cxx}"
export CFLAGS="${RPM_OPT_FLAGS} -Wno-unused"
export CXXFLAGS="${RPM_OPT_FLAGS} -Wno-unused"

%{__make} \
	native                \
	library=shared        \
	soname_version=%{maj} \
	console=readline      \
	disassembler=on       \
	gdbjit=on             \
	liveobjectlist=on     \
	werror=no             \
	strictaliasing=off    \
	V=1                   \
	%{?_smp_mflags}


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_bindir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_includedir}/%{name}/extensions
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig
%{__mkdir_p} ${RPM_BUILD_ROOT}%{python_sitelib}

%{__install} -m 0755 out/native/d8    ${RPM_BUILD_ROOT}%{_bindir}

%{__install} -m 0644 include/v8*.h    ${RPM_BUILD_ROOT}%{_includedir}
pushd src
%{__install} -m 0644 extensions/*.h   ${RPM_BUILD_ROOT}%{_includedir}/%{name}/extensions
popd

pushd out/native/lib.target
for LIB in libv8.so libv8icui18n.so libv8icuuc.so; do
  %{__install} -m 0755 ${LIB}.%{maj}  ${RPM_BUILD_ROOT}%{_libdir}/${LIB}.%{ver}
  %{__ln_s}    -f      ${LIB}.%{ver}  ${RPM_BUILD_ROOT}%{_libdir}/${LIB}
done
popd

pushd out/native/obj.target/tools/gyp
for AR in libv8_base libv8_nosnapshot; do
  %{__install} -m 0644 ${AR}.*.a      ${RPM_BUILD_ROOT}%{_libdir}/${AR}.a
done
%{__install} -m 0644 libv8_snapshot.a ${RPM_BUILD_ROOT}%{_libdir}
%{__ln_s}    -f      libv8_base.a     ${RPM_BUILD_ROOT}%{_libdir}/libv8.a
popd

#pushd out/native/obj.target/third_party/icu
#%{__install} -m 0644 libv8icu[iu]*.a  ${RPM_BUILD_ROOT}%{_libdir}
#popd

%{__install} -m 0644 %{name}.pc       ${RPM_BUILD_ROOT}%{_libdir}/pkgconfig

# Install JS minifier scripts
%{__install} -m 0755 tools/js*.py     ${RPM_BUILD_ROOT}%{python_sitelib}


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog LICENSE* OWNERS
%{_bindir}/d8
%{_libdir}/libv8.so.*
%{_libdir}/libv8icui18n.so.*
%{_libdir}/libv8icuuc.so.*

%files devel
%defattr(-,root,root)
%doc --parents benchmarks samples/*.{cc,js}
%{_includedir}/v8*.h
%{_includedir}/%{name}
%{_libdir}/libv8.so
%{_libdir}/libv8icui18n.so
%{_libdir}/libv8icuuc.so
%{_libdir}/pkgconfig/%{name}.pc
%{python_sitelib}/js2c.py*
%{python_sitelib}/jsmin.py*

%files static
%defattr(-,root,root)
%{_libdir}/libv8.a
%{_libdir}/libv8_base.a
%{_libdir}/libv8_nosnapshot.a
%{_libdir}/libv8_snapshot.a
#%{_libdir}/libv8icui18n.a
#%{_libdir}/libv8icuuc.a


%changelog
* Sun Mar 16 2014 Peter Pramberger <peterpramb@member.fsf.org> - 3.25.12-1
- Initial build
